@@ -1,6 +1,6 @@
 package Mail::DMARC::Base;
 {
-  $Mail::DMARC::Base::VERSION = '1.20130528';
+  $Mail::DMARC::Base::VERSION = '1.20130531';
 }
 use strict;
 use warnings;
@@ -182,6 +182,7 @@ sub is_valid_domain {
 sub is_valid_spf_scope {
     my ($self, $scope ) = @_;
     return lc $scope if grep { lc $scope eq $_ } qw/ mfrom helo /;
+    carp "$scope is not a valid SPF scope";
     return;
 };
 
@@ -189,6 +190,7 @@ sub is_valid_spf_result {
     my ($self, $result ) = @_;
     return 1 if grep { lc $result eq $_ }
         qw/ fail neutral none pass permerror softfail temperror /;
+    carp "$result is not a valid SPF result";
     return;
 };
 
@@ -217,7 +219,7 @@ Mail::DMARC::Base - DMARC utility functions
 
 =head1 VERSION
 
-version 1.20130528
+version 1.20130531
 
 =head1 METHODS
 
